'---------------------------------------------------------------------
'  Copyright (C) Microsoft Corporation.  All rights reserved.
' 
'THIS CODE AND INFORMATION ARE PROVIDED AS IS WITHOUT WARRANTY OF ANY
'KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
'IMPLIED WARRANTIES OF MERCHANTABILITY AND/OR FITNESS FOR A
'PARTICULAR PURPOSE.
'---------------------------------------------------------------------

Option Explicit On
Option Strict On

Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.ComponentModel.Design
Imports System.Drawing
Imports System.Text
Imports System.Windows.Forms
Imports System.Windows.Forms.Design.Behavior

Namespace Extensions

    Friend Class PaddingGlyph
        Inherits BoundsGlyph

        Friend Sub New( _
        ByVal c As Control, _
        ByVal behaviorService As BehaviorService, _
        ByVal changeService As IComponentChangeService, _
        ByVal selectionService As ISelectionService, _
        ByVal referenceService As IReferenceService, _
        ByVal serviceProvider As IServiceProvider, _
        ByVal adorner As Adorner)

            MyBase.New( _
                c, _
                behaviorService, _
                changeService, _
                selectionService, _
                referenceService, _
                serviceProvider, _
                New PaddingBehavior(serviceProvider), _
                adorner)

            Me.propertyName = "Padding"
        End Sub

        Protected Overrides Sub ComputeGeometry()
            Dim c As Control = Me.relatedControlValue

            Dim controlRect As Rectangle = _
                Me.behaviorService.ControlRectInAdornerWindow(c)

            Dim halfHitTestWidth As Integer = CInt(Me.hitTestWidth / 2)

            Dim leftBound As Integer = controlRect.Left + c.Padding.Left
            Dim topBound As Integer = controlRect.Top + c.Padding.Top
            Dim widthBound As Integer = controlRect.Width - c.Padding.Left - c.Padding.Right
            Dim heightBound As Integer = controlRect.Height - c.Padding.Top - c.Padding.Bottom

            Me.boundsLeftRect = New Rectangle( _
                leftBound - halfHitTestWidth, _
                topBound + halfHitTestWidth, _
                Me.HitTestWidth, _
                heightBound - Me.HitTestWidth)

            Me.boundsTopRect = New Rectangle( _
                leftBound + halfHitTestWidth, _
                topBound - halfHitTestWidth, _
                widthBound - Me.HitTestWidth, _
                Me.HitTestWidth)

            Me.boundsRightRect = New Rectangle( _
                leftBound + widthBound - halfHitTestWidth, _
                topBound + halfHitTestWidth, _
                Me.HitTestWidth, _
                heightBound - Me.HitTestWidth)

            Me.boundsBottomRect = New Rectangle( _
                leftBound + halfHitTestWidth, _
                topBound + heightBound - halfHitTestWidth, _
                widthBound - Me.HitTestWidth, _
                Me.HitTestWidth)

            Me.boundsValue = New Rectangle( _
                leftBound, _
                topBound, _
                widthBound, _
                heightBound)
        End Sub

    End Class

End Namespace
